@@ -1,17 +1,18 @@
 # -*- coding: utf-8 -*-
 from django.test import TestCase
-from utils import api
-from models import User, Status
-from factories import UserFactory, StatusFactory
 import tweepy
 
+from .factories import UserFactory, StatusFactory
+from .models import User, Status
+from .utils import api
+
+
 STATUS_ID = 327926550815207424
 USER_ID = 813286
 USER_SCREEN_NAME = 'BarackObama'
 USER1_ID = 18807761
 USER1_SCREEN_NAME = 'voronezh'
-#USER2_ID = 16477634
-#USER2_SCREEN_NAME = 'durov'
+
 
 class TwitterApiTest(TestCase):
 
@@ -30,7 +31,7 @@ class TwitterApiTest(TestCase):
         instance = User.remote.fetch(USER_ID)
 
         self.assertEqual(instance.screen_name, USER_SCREEN_NAME)
-        self.assertTrue(isinstance(instance.tweepy, tweepy.models.User))
+        self.assertIsInstance(instance.tweepy, tweepy.models.User)
         self.assertEqual(instance.tweepy.id_str, str(USER_ID))
 
     def test_fetch_status(self):
@@ -60,9 +61,9 @@ class TwitterApiTest(TestCase):
         self.assertEqual(instance.location, 'Washington, DC')
         self.assertEqual(instance.verified, True)
         self.assertEqual(instance.lang, 'en')
-        self.assertTrue(instance.followers_count > 30886141)
-        self.assertTrue(instance.friends_count > 660030)
-        self.assertTrue(instance.listed_count > 192107)
+        self.assertGreater(instance.followers_count, 30886141)
+        self.assertGreater(instance.friends_count, 600000)
+        self.assertGreater(instance.listed_count, 192107)
 
         instance1 = User.remote.fetch(USER_SCREEN_NAME)
         self.assertEqual(instance.name, instance1.name)
@@ -70,45 +71,52 @@ class TwitterApiTest(TestCase):
 
     def test_fetch_user_statuses(self):
 
-        instance = UserFactory.create(id=USER_ID)
+        instance = UserFactory(id=USER_ID)
 
         self.assertEqual(Status.objects.count(), 0)
+
         instances = instance.fetch_statuses(count=30)
+
         self.assertEqual(len(instances), 30)
-        self.assertEqual(len(instances), Status.objects.count())
+        self.assertEqual(len(instances), Status.objects.filter(author=instance).count())
 
         instances = instance.fetch_statuses(all=True, exclude_replies=True)
-        self.assertTrue(len(instances) > 3100)
-        self.assertTrue(len(instances) < 8000)
-        self.assertEqual(len(instances), Status.objects.count())
+
+        self.assertGreater(len(instances), 3100)
+        self.assertLess(len(instances), 4000)
+        self.assertEqual(len(instances), Status.objects.filter(author=instance).count())
 
     def test_fetch_user_followers(self):
 
-        instance = UserFactory.create(id=USER1_ID)
+        instance = UserFactory(id=USER1_ID)
 
         self.assertEqual(User.objects.count(), 1)
         instances = instance.fetch_followers(all=True)
-        self.assertTrue(len(instances) > 870)
-        self.assertTrue(len(instances) < 1000)
-        self.assertTrue(isinstance(instances[0], User))
-        self.assertEqual(len(instances), User.objects.count()-1)
+        self.assertGreater(len(instances), 870)
+        self.assertLess(len(instances), 2000)
+        self.assertIsInstance(instances[0], User)
+        self.assertEqual(len(instances), User.objects.count() - 1)
 
     def test_fetch_user_followers_ids(self):
 
-        instance = UserFactory.create(id=USER1_ID)
+        instance = UserFactory(id=USER1_ID)
 
         self.assertEqual(User.objects.count(), 1)
-        ids = instance.fetch_followers_ids(all=True)
-        self.assertTrue(len(ids) > 870)
-        self.assertTrue(len(ids) < 1000)
-        self.assertTrue(isinstance(ids[0], int))
+
+        ids = instance.get_followers_ids(all=True)
+
+        self.assertGreater(len(ids), 1000)
+        self.assertLess(len(ids), 2000)
+        self.assertIsInstance(ids[0], long)
         self.assertEqual(User.objects.count(), 1)
 
     def test_fetch_status_retweets(self):
 
-        instance = StatusFactory.create(id=329231054282055680)
+        instance = StatusFactory(id=329231054282055680)
 
         self.assertEqual(Status.objects.count(), 1)
+
         instances = instance.fetch_retweets()
-        self.assertTrue(len(instances) >= 10)
-        self.assertEqual(len(instances), Status.objects.count()-1)
\ No newline at end of file
+
+        self.assertGreaterEqual(len(instances), 6)
+        self.assertEqual(len(instances), Status.objects.count() - 1)
